@@ -429,7 +429,8 @@ static int mkdir_p(const char *path) {
 }
 
 /* Compile C file to shared object */
-int xs_jit_compile_file(pTHX_ const char *c_file, const char *so_file) {
+int xs_jit_compile_file(pTHX_ const char *c_file, const char *so_file,
+                        const char *extra_cflags, const char *extra_ldflags) {
     HV *config = get_hv("Config::Config", 0);
     if (!config) {
         warn("XS::JIT: Cannot access %%Config");
@@ -450,15 +451,19 @@ int xs_jit_compile_file(pTHX_ const char *c_file, const char *so_file) {
     const char *lddlflags = (lddlflags_sv && *lddlflags_sv) ? SvPV_nolen(*lddlflags_sv) : "";
     const char *archlib = (archlib_sv && *archlib_sv) ? SvPV_nolen(*archlib_sv) : "";
 
+    /* Default to empty string if NULL */
+    if (!extra_cflags) extra_cflags = "";
+    if (!extra_ldflags) extra_ldflags = "";
+
     char o_file[MAX_PATH_LEN];
     snprintf(o_file, sizeof(o_file), "%s.o", c_file);
 
-    char cmd[MAX_PATH_LEN * 2];
+    char cmd[MAX_PATH_LEN * 4];  /* Larger buffer for extra flags */
     int ret;
 
-    /* Compile to object with optimization */
-    snprintf(cmd, sizeof(cmd), "%s %s %s %s -c -o \"%s\" -I\"%s/CORE\" \"%s\" 2>&1",
-             cc, ccflags, optimize, cccdlflags, o_file, archlib, c_file);
+    /* Compile to object with optimization and extra cflags */
+    snprintf(cmd, sizeof(cmd), "%s %s %s %s %s -c -o \"%s\" -I\"%s/CORE\" \"%s\" 2>&1",
+             cc, ccflags, optimize, cccdlflags, extra_cflags, o_file, archlib, c_file);
 
     ret = system(cmd);
     if (ret != 0) {
@@ -466,9 +471,9 @@ int xs_jit_compile_file(pTHX_ const char *c_file, const char *so_file) {
         return 0;
     }
 
-    /* Link to shared object */
-    snprintf(cmd, sizeof(cmd), "%s %s -o \"%s\" \"%s\" 2>&1",
-             cc, lddlflags, so_file, o_file);
+    /* Link to shared object with extra ldflags */
+    snprintf(cmd, sizeof(cmd), "%s %s %s -o \"%s\" \"%s\" 2>&1",
+             cc, lddlflags, extra_ldflags, so_file, o_file);
 
     ret = system(cmd);
     if (ret != 0) {
@@ -648,7 +653,8 @@ static int functions_already_loaded(pTHX_ XS_JIT_Func *functions, int num_functi
 /* Main compile function */
 int xs_jit_compile(pTHX_ const char *code, const char *name,
                    XS_JIT_Func *functions, int num_functions,
-                   const char *cache_dir, int force) {
+                   const char *cache_dir, int force,
+                   const char *extra_cflags, const char *extra_ldflags) {
     char so_path[MAX_PATH_LEN];
     char c_path[MAX_PATH_LEN];
     char dir_path[MAX_PATH_LEN];
@@ -705,8 +711,8 @@ int xs_jit_compile(pTHX_ const char *code, const char *name,
     fclose(fp);
     free(generated);
 
-    /* Compile */
-    if (!xs_jit_compile_file(aTHX_ c_path, so_path)) {
+    /* Compile with extra flags */
+    if (!xs_jit_compile_file(aTHX_ c_path, so_path, extra_cflags, extra_ldflags)) {
         return 0;
     }
 
